interests

# XMLRésuméLibrary: User Guide

interest | Element Reference | job

## Name

interests — Container for one or more interests

## Synopsis

### Content Model

    (title?,interest+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `interests` element contains one or more `interest` elements.

### Formatting

The `interests` element is formatted as a top-level section in a résumé. The `interests.word` parameter is used as the title text if the `interests` doesn't contain a `title` element.

Child `interest` elements are formatted as a bulleted list in all output formats.

### Parents

`interests` may be contained in these elements: `resume`

## See Also

`skillarea`.

## Examples

    <interests>
      <title>Hobbies</title>
      <interest>
        <title>Swimming</title>
      </interest>
      <interest>
        <title>Fine foods</title>
        <description>
          <para>I do quite well in pie-eating contests.</para>
        </description>
      </interest>
      <interest>
        <title>Australia</title>
      </interest>
    </interests>

    <interests>
      <interest>
        <title>My belly button</title>
      </interest>
      <interest>
        <title>Fire ants</title>
      </interest>
      <interest>
        <title>Fertilizer</title>
      </interest>
    </interests>

interest | Element Reference | job